messagelisttest

package
v1.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package messagelisttest provides test helpers for the messagelist package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(t *testing.T, width, height int) *messagelist.Model

New creates a messagelist.Model wired with test dependencies. Uses a real SQLite database, mock chat client, real theme, and test logger.

Types

This section is empty.

Jump to